@@ -49,13 +49,13 @@ test_that("backtest results coincide with PerformanceAnalytics and base R", {
   w_EWP <- rep(1/N, N)
   ret_direct <- xts(X_lin %*% w_EWP, index(X_lin))
   wealth_direct <- xts(c(1, cumprod(1 + ret_direct)), index(prices))  # compounded (initial budget of 1$)
-  expect_equal(ret_portfolioBacktest, ret_direct, check.attributes = FALSE)
-  expect_equal(wealth_portfolioBacktest, wealth_direct, check.attributes = FALSE)
+  expect_equivalent(ret_portfolioBacktest, ret_direct)
+  expect_equivalent(wealth_portfolioBacktest, wealth_direct)
   
   # compare with PerformanceAnalytics
   PerfAnal <- PerformanceAnalytics::Return.portfolio(X_lin, weights = w_EWP, rebalance_on = "days", verbose = TRUE)
-  expect_equal(ret_portfolioBacktest, PerfAnal$returns, check.attributes = FALSE)
-  expect_equal(bt$Uniform$`dataset 1`$w_bop, PerfAnal$BOP.Weight, check.attributes = FALSE)
+  expect_equivalent(ret_portfolioBacktest, PerfAnal$returns)
+  expect_equivalent(bt$Uniform$`dataset 1`$w_bop, PerfAnal$BOP.Weight)
   
   
   #
@@ -74,8 +74,8 @@ test_that("backtest results coincide with PerformanceAnalytics and base R", {
   
   # compare with PerformanceAnalytics
   PerfAnal <- PerformanceAnalytics::Return.portfolio(X_lin, weights = bt$Uniform$`dataset 1`$w_designed, verbose = TRUE)
-  expect_equal(ret_portfolioBacktest, PerfAnal$returns, check.attributes = FALSE)
-  expect_equal(bt$Uniform$`dataset 1`$w_bop, PerfAnal$BOP.Weight, check.attributes = FALSE)  
+  expect_equivalent(ret_portfolioBacktest, PerfAnal$returns)
+  expect_equivalent(bt$Uniform$`dataset 1`$w_bop, PerfAnal$BOP.Weight)  
   
 
   #
@@ -86,10 +86,10 @@ test_that("backtest results coincide with PerformanceAnalytics and base R", {
   # compare with PerformanceAnalytics
   expect_warning(PerfAnal <- PerformanceAnalytics::Return.portfolio(X_lin, weights = bt$GMVP$`dataset 1`$w_designed, verbose = TRUE), 
                  "The weights for one or more periods do not sum up to 1: assuming a return of 0 for the residual weights")
-  expect_equal(ret_portfolioBacktest, PerfAnal$returns, check.attributes = FALSE)
-  expect_equal(bt$GMVP$`dataset 1`$w_bop, PerfAnal$BOP.Weight[, 1:2], check.attributes = FALSE)
+  expect_equivalent(ret_portfolioBacktest, PerfAnal$returns)
+  expect_equivalent(bt$GMVP$`dataset 1`$w_bop, PerfAnal$BOP.Weight[, 1:2])
   cash <- 1 - rowSums(bt$GMVP$`dataset 1`$w_bop)
-  expect_equal(cash, as.vector(PerfAnal$BOP.Weight[, 3]), check.attributes = FALSE)
+  expect_equivalent(cash, as.vector(PerfAnal$BOP.Weight[, 3]))
   
   
   #
@@ -103,7 +103,7 @@ test_that("backtest results coincide with PerformanceAnalytics and base R", {
                           execution = "next day",
                           return_portfolio = TRUE, 
                           return_returns = TRUE)
-  expect_equal(bt$Uniform$`dataset 1`$w_designed, bt_next_day$Uniform$`dataset 1`$w_designed)
+  expect_equivalent(bt$Uniform$`dataset 1`$w_designed, bt_next_day$Uniform$`dataset 1`$w_designed)
   w_designed_lagged <- prices
   w_designed_lagged[] <- NA
   w_designed_lagged[index(bt$Uniform$`dataset 1`$w_designed), ] <- bt$Uniform$`dataset 1`$w_designed
@@ -112,8 +112,8 @@ test_that("backtest results coincide with PerformanceAnalytics and base R", {
   
   # compare with PerformanceAnalytics
   PerfAnal_next_day <- PerformanceAnalytics::Return.portfolio(X_lin, weights = w_designed_lagged, verbose = TRUE)
-  expect_equal(bt_next_day$Uniform$`dataset 1`$return, PerfAnal_next_day$returns, check.attributes = FALSE)
-  expect_equal(bt_next_day$Uniform$`dataset 1`$w_bop, PerfAnal_next_day$BOP.Weight, check.attributes = FALSE)
+  expect_equivalent(bt_next_day$Uniform$`dataset 1`$return, PerfAnal_next_day$returns)
+  expect_equivalent(bt_next_day$Uniform$`dataset 1`$w_bop, PerfAnal_next_day$BOP.Weight)
 })
   
 
@@ -127,23 +127,23 @@ test_that("backtest results and performance measures coincide with the precomput
   # bt_check <- bt$GMVP$`dataset 1`[-2]
   # save(bt_check, file = "bt_check.RData", version = 2)
   load("bt_check.RData")
-  expect_equal(bt$GMVP$`dataset 1`[-2], bt_check) 
+  expect_equivalent(bt$GMVP$`dataset 1`[-2], bt_check)
 
   # bt_selector_check <- backtestSelector(bt, portfolio_name = "Uniform")$performance
   # save(bt_selector_check, file = "bt_selector_check.RData", version = 2)
   load("bt_selector_check.RData")
-  expect_equal(backtestSelector(bt, portfolio_name = "Uniform")$performance, bt_selector_check)
+  expect_equivalent(backtestSelector(bt, portfolio_name = "Uniform")$performance, bt_selector_check)
   
   # bt_table_check <- backtestTable(bt)[1:8]
   # save(bt_table_check, file = "bt_table_check.RData", version = 2)
   load("bt_table_check.RData")
-  expect_equal(backtestTable(bt)[1:8], bt_table_check) 
+  expect_equivalent(backtestTable(bt)[1:8], bt_table_check) 
   
   # bt_summary_check <- backtestSummary(bt, summary_fun = median)[1:2]
-  # save(bt_summary_check, file = "bt_summary_check.RData")
+  # save(bt_summary_check, file = "bt_summary_check.RData", version = 2)
   load("bt_summary_check.RData")
   bt_summary <- backtestSummary(bt, summary_fun = median)[1:2]
-  expect_equal(backtestSummary(bt, summary_fun = median)[1:2], bt_summary)  # compare except cpu time
+  expect_equivalent(backtestSummary(bt, summary_fun = median)[1:2], bt_summary)  # compare except cpu time
 })
 
 
@@ -168,13 +168,13 @@ test_that("backtest results with bankruptcy work fine", {
   #plot(cbind(stock_price_normalized, bt$fun1$`dataset 1`$wealth))
   
   # check bankruptcy_dates
-  expect_equal(index(stock_price_normalized[stock_price_normalized <= 0])[1],
-               index(bt$fun1$`dataset 1`$wealth[bt$fun1$`dataset 1`$wealth <= 0])[1])
+  expect_equivalent(index(stock_price_normalized[stock_price_normalized <= 0])[1],
+                    index(bt$fun1$`dataset 1`$wealth[bt$fun1$`dataset 1`$wealth <= 0])[1])
   bankruptcy_date <- index(stock_price_normalized[stock_price_normalized <= 0])[1]
   
   # check whole time series until bankruptcy
-  expect_equal(stock_price_normalized[paste0("::", bankruptcy_date)],
-               bt$fun1$`dataset 1`$wealth[paste0("::", bankruptcy_date)], check.attributes = FALSE)
+  expect_equivalent(stock_price_normalized[paste0("::", bankruptcy_date)],
+                    bt$fun1$`dataset 1`$wealth[paste0("::", bankruptcy_date)])
 })
 
 
@@ -190,7 +190,7 @@ test_that("transaction cost works properly", {
                           cost = list(buy = 0, sell = 0),
                           return_portfolio = TRUE, return_returns = TRUE,
                           T_rolling_window = 252, optimize_every = 20, rebalance_every = 5)
-  expect_equal(bt$Uniform$`dataset 1`[-2], bt2$Uniform$`dataset 1`[-2])
+  expect_equivalent(bt$Uniform$`dataset 1`[-2], bt2$Uniform$`dataset 1`[-2])
 
   bt_tc <- portfolioBacktest(portfolios[1], dataset_list = dataset10[1],
                            shortselling = TRUE, leverage = Inf,
@@ -198,15 +198,15 @@ test_that("transaction cost works properly", {
                            return_portfolio = TRUE, return_returns = TRUE,
                            T_rolling_window = 252, optimize_every = 20, rebalance_every = 5)
   
-  expect_equal(bt$Uniform$`dataset 1`[c("error", "error_message", "w_designed")], 
-               bt_tc$Uniform$`dataset 1`[c("error", "error_message", "w_designed")])
-  expect_equal(bt$Uniform$`dataset 1`$w_bop,
-               bt_tc$Uniform$`dataset 1`$w_bop, tolerance = 1e-5)
-  expect_equal(bt$Uniform$`dataset 1`$return,
-               bt_tc$Uniform$`dataset 1`$return, tolerance = 2e-4)
+  expect_equivalent(bt$Uniform$`dataset 1`[c("error", "error_message", "w_designed")], 
+                    bt_tc$Uniform$`dataset 1`[c("error", "error_message", "w_designed")])
+  expect_equivalent(bt$Uniform$`dataset 1`$w_bop,
+                    bt_tc$Uniform$`dataset 1`$w_bop, tolerance = 1e-5)
+  expect_equivalent(bt$Uniform$`dataset 1`$return,
+                    bt_tc$Uniform$`dataset 1`$return, tolerance = 2e-4)
   #plot(cbind(bt$Uniform$`dataset 1`$return, bt_tc$Uniform$`dataset 1`$return))
-  expect_equal(bt$Uniform$`dataset 1`$wealth,
-               bt_tc$Uniform$`dataset 1`$wealth, tolerance = 2e-4)
+  expect_equivalent(bt$Uniform$`dataset 1`$wealth,
+                    bt_tc$Uniform$`dataset 1`$wealth, tolerance = 2e-4)
   #plot(cbind(bt$Uniform$`dataset 1`$wealth, bt_tc$Uniform$`dataset 1`$wealth))
 })
 
@@ -230,20 +230,20 @@ test_that("cash is properly accounted in backtest results", {
   first_date_trading <- index(bt$fun1$`dataset 1`$wealth)[1]
   stock_price_normalized <- dataset10_bankruptcy$`dataset 1`$adjusted[paste0(first_date_trading, "::"), 1]/as.numeric(dataset10_bankruptcy$`dataset 1`$adjusted[first_date_trading, 1])
   #plot(cbind(stock_price_normalized, bt$fun1$`dataset 1`$wealth), lwd = c(2, 4))
-  expect_equal(stock_price_normalized, bt$fun1$`dataset 1`$wealth, check.attributes = FALSE)
+  expect_equivalent(stock_price_normalized, bt$fun1$`dataset 1`$wealth)
 
     
   # second, all in cash
   stock1_portfolio_fun <- function(dataset, prices = dataset$adjusted) {
     return(c(0, rep(0, ncol(prices)-1)))
   }
-  bt <- portfolioBacktest(stock1_portfolio_fun, dataset_list = dataset10_bankruptcy,
-                          shortselling = TRUE, leverage = Inf, 
-                          return_portfolio = TRUE, return_returns = TRUE, 
-                          benchmark = c("uniform", "index"),
-                          T_rolling_window = 252, optimize_every = 20, rebalance_every = 5)
+  bt <- suppressWarnings(expr = portfolioBacktest(stock1_portfolio_fun, dataset_list = dataset10_bankruptcy,
+                                                  shortselling = TRUE, leverage = Inf, 
+                                                  return_portfolio = TRUE, return_returns = TRUE, 
+                                                  benchmark = c("uniform", "index"),
+                                                  T_rolling_window = 252, optimize_every = 20, rebalance_every = 5))
   #plot(cbind(stock_price_normalized, bt$fun1$`dataset 1`$wealth), lwd = c(2, 4))
-  expect_equal(sum(abs(bt$fun1$`dataset 1`$wealth - 1)), 0)
+  expect_equivalent(sum(abs(bt$fun1$`dataset 1`$wealth - 1)), 0)
     
   # # third, partially invested
   # stock1_portfolio_fun <- function(dataset, prices = dataset$adjusted) {
@@ -287,7 +287,7 @@ test_that("portfolioBacktest over files", {
                                 T_rolling_window = 252, optimize_every = 20, rebalance_every = 5)
   bt_files <- lapply(bt_files, function(x) {sapply(x, function(x) {x$performance})})
   load("bt_files_check.RData")
-  expect_equal(bt_files, bt_files_check)
+  expect_equivalent(bt_files, bt_files_check)
   # bt_files_check <- bt_files
   # save(bt_files_check, file = "bt_files_check.RData", version = 2, compression_level = 9)
 })
