@@ -9,6 +9,6 @@ portfolio_fun <- function(data) {
   w <- Variable(nrow(Sigma))
   prob <- Problem(Maximize(t(mu) %*% w - lmd*quad_form(w, Sigma)),
                   constraints = list(w >= 0, sum(w) == 1))
-  result <- solve(prob)
+  result <- CVXR::solve(prob)
   return(as.vector(result$getValue(w)))
 }
