@@ -8,6 +8,6 @@ portfolio_fun <- function(data) {
   w_ <- Variable(nrow(Sigma))
   prob <- Problem(Minimize(quad_form(w_, Sigma)),
                   constraints = list(w_ >= 0, t(mu) %*% w_ == 1))
-  result <- solve(prob)
+  result <- CVXR::solve(prob)
   return(as.vector(result$getValue(w_)/sum(result$getValue(w_))))
 }
